chiark / gitweb /
Commit as 2.1.0.
[mLib] / selpk.c
diff --git a/selpk.c b/selpk.c
index 9d077b6745cb137a66185a25a7efc79b7ad1f646..f035dd610297d688aa7acf2ad293d40fddd1ad51 100644 (file)
--- a/selpk.c
+++ b/selpk.c
@@ -1,13 +1,13 @@
 /* -*-c-*-
  *
- * $Id: selpk.c,v 1.1 2000/06/17 10:39:19 mdw Exp $
+ * $Id: selpk.c,v 1.3 2004/04/08 01:36:13 mdw Exp $
  *
  * Packet-buffering select handler
  *
  * (c) 1999 Straylight/Edgeware
  */
 
-/*----- Licensing notice --------------------------------------------------* 
+/*----- Licensing notice --------------------------------------------------*
  *
  * This file is part of the mLib utilities library.
  *
  * it under the terms of the GNU Library General Public License as
  * published by the Free Software Foundation; either version 2 of the
  * License, or (at your option) any later version.
- * 
+ *
  * mLib is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU Library General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Library General Public
  * License along with mLib; if not, write to the Free
  * Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
  * MA 02111-1307, USA.
  */
 
-/*----- Revision history --------------------------------------------------* 
- *
- * $Log: selpk.c,v $
- * Revision 1.1  2000/06/17 10:39:19  mdw
- * Experimental new support for packet buffering.
- *
- */
-
 /*----- Header files ------------------------------------------------------*/
 
 #include <errno.h>
@@ -145,7 +137,7 @@ void selpk_want(selpk *pk, size_t sz)
  * Arguments:  @selpk *pk@ = pointer to buffer block
  *             @sel_state *s@ = pointer to select state to attach to
  *             @int fd@ = file descriptor to listen to
*             @void (*func)(char *s, void *p)@ = function to call
  *             @void *p@ = argument for function
  *
  * Returns:    ---
@@ -153,12 +145,7 @@ void selpk_want(selpk *pk, size_t sz)
  * Use:                Initializes a buffer block.
  */
 
-void selpk_init(selpk *pk,
-                sel_state *s,
-                int fd,
-                void (*func)(octet */*b*/, size_t /*sz*/, pkbuf */*pk*/,
-                             size_t */*keep*/, void */*p*/),
-                void *p)
+void selpk_init(selpk *pk, sel_state *s, int fd, pkbuf_func *func, void *p)
 {
   pkbuf_init(&pk->pk, func, p);
   pk->pk.f &= ~PKBUF_ENABLE;
@@ -145,7 +137,7 @@ void selpk_want(selpk *pk, size_t sz)
  *             @sel_state *s@ = pointer to select state to attach to
  *             @int fd@ = file descriptor to listen to
- *             @void (*func)(char *s, void *p)@ = function to call
+ *             @pkbuf_func *func@ = function to call
  *             @void *p@ = argument for function
  *